import React from 'react'
import Select from '../postproperty/Select';

const amenitiesList = [
  "GYM", "Drainage", "Children Park", "Main Entrance Gate", 
  "Landscaping", "Plantation", "Internal Road", "Boundary Wall", 
  "Security Service", "Temple", "Water", "Electricity", "Drainage system"
];

const ProjectAmenities = ({ 
  selectedAmenities,
  setSelectedAmenities,

  plotSize,
  setPlotSize,

  plotSizeUnit,
  setPlotSizeUnit,

  numberOfPlots,
  setNumberOfPlots,

  pricePerUnit,
  setPricePerUnit,

  priceUnit,
  setPriceUnit
}) => {
  // Toggle amenity selection
  const toggleAmenity = (amenity) => {
    setSelectedAmenities(prev => 
      prev.includes(amenity)
        ? prev.filter(item => item !== amenity)
        : [...prev, amenity]
    );
  };

  return (
    <div className='container mx-auto px-4 sm:px-6 lg:px-8 max-w-4xl'>
      <div className='flex flex-col gap-6'>
        <p className='font-semibold text-2xl sm:text-3xl md:text-4xl text-center'>
          Project Amenities
        </p>
        
        {/* Amenities Grid */}
        <div className='grid grid-cols-2 sm:grid-cols-3 md:grid-cols-4 gap-4'>
          {amenitiesList.map(item => (
            <div 
              key={item} 
              className="flex items-center gap-2 cursor-pointer"
              onClick={() => toggleAmenity(item)}
            >
              <input 
                type="checkbox" 
                checked={selectedAmenities.includes(item)}
                onChange={() => toggleAmenity(item)}
                className='text-brand focus:ring-brand rounded'
              />
              <p className='font-light text-sm sm:text-base'>{item}</p>
            </div>
          ))}
        </div>

        {/* Plot Size Input */}
        <div className='flex flex-col gap-2'>
          <label className='text-sm font-medium text-gray-700'>
Expected Project Price
          </label>
          <div className="flex gap-2">
            <input 
              type="number"
              placeholder="Enter Price"
              value={plotSize}
              onChange={(e) => setPlotSize(e.target.value)}
              className='flex-grow px-3 py-2 border border-gray-300 rounded-md 
                         focus:outline-none focus:ring-2 focus:ring-brand 
                         text-sm sm:text-base'
            />
            <Select 
              value={plotSizeUnit}
              onChange={(e) => setPlotSizeUnit(e.target.value)}
              className='w-32 sm:w-40'
            >
              <option value="SQ Yard">SQ Yard</option>
              <option value="SQ Meter">SQ Meter</option>
              <option value="Acre">Acre</option>
            </Select>
          </div>
        </div>

        {/* Number of Plots and Price */}
        <div className='grid sm:grid-cols-2 gap-4'>
          {/* Number of Plots */}
          <div className='flex flex-col gap-2'>
            <label className='text-sm font-medium text-gray-700'>
              Number of Plots
            </label>
            <input 
              type="number"
              placeholder="How many Plots"
              value={numberOfPlots}
              onChange={(e) => setNumberOfPlots(e.target.value)}
              className='w-full px-3 py-2 border border-gray-300 rounded-md 
                         focus:outline-none focus:ring-2 focus:ring-brand 
                         text-sm sm:text-base'
            />
          </div>

          {/* Price per Unit */}
          <div className='flex flex-col gap-2'>
            <label className='text-sm font-medium text-gray-700'>
              Price per Unit
            </label>
            <div className="flex gap-2">
              <input 
                type="number"
                placeholder="Price per unit"
                value={pricePerUnit}
                onChange={(e) => setPricePerUnit(e.target.value)}
                className='flex-grow px-3 py-2 border border-gray-300 rounded-md 
                           focus:outline-none focus:ring-2 focus:ring-brand 
                           text-sm sm:text-base'
              />
              <Select 
                value={priceUnit}
                onChange={(e) => setPriceUnit(e.target.value)}
                className='w-32 sm:w-40'
              >
                <option value="SQ Yard">SQ Yard</option>
                <option value="SQ Meter">SQ Meter</option>
                <option value="Plot">Plot</option>
              </Select>
            </div>
          </div>
        </div>
      </div>
    </div>
  )
}

export default ProjectAmenities